#[repr(C)]pub enum ErrorModel {
Dynamic = 0,
Static = 1,
}Expand description
Error model for a language runtime.
Describes whether a runtime’s foreign function calls can fail at runtime due to the inherent dynamism of the language.
Variants
Dynamic = 0
Runtime errors are possible on every call (Python, JS, Ruby).
Foreign function return types are automatically wrapped in Result<T>.
Static = 1
The language has compile-time type safety. Foreign functions return
T directly; runtime errors are not expected under normal operation.